@@ -27,7 +27,7 @@ from grokcore.view.meta.directoryresource import _get_resource_path
 from martian.error import GrokError
 
 from Products.Five.security import protectClass, protectName
-from Globals import InitializeClass as initializeClass
+from App.class_init import InitializeClass as initializeClass
 
 import os.path
 
@@ -151,26 +151,3 @@ class ViewletSecurityGrokker(martian.ClassGrokker):
 
         return True
 
-@grokcore.component.provider(grokcore.site.interfaces.IUtilityInstaller)
-def setupUtility(site, utility, provides, name=u'',
-                 name_in_container=None, public=False, setup=None):
-    """Set up a utility in a site in Zope2. It's different than Zope3,
-    because before Zope 2.12, setting up an object using [] doesn't
-    work. See the original implementation for more details.
-    """
-    site_manager = site.getSiteManager()
-
-    if not public:
-        container = site_manager
-    else:
-        container = site
-
-    if name_in_container is None:
-        name_in_container = INameChooser(container).chooseName(
-            utility.__class__.__name__, utility)
-    container._setObject(name_in_container, utility)
-
-    if setup is not None:
-        setup(utility)
-
-    site_manager.registerUtility(utility, provided=provides, name=name)
